summary | shortlog | log | commit | commitdiff | tree
raw | patch | inline | side by side (parent: 1370f3f)
raw | patch | inline | side by side (parent: 1370f3f)
author | Olivier Crête <olivier.crete@collabora.co.uk> | |
Tue, 21 Sep 2010 23:33:10 +0000 (19:33 -0400) | ||
committer | Olivier Crête <olivier.crete@collabora.co.uk> | |
Wed, 30 Mar 2011 00:08:40 +0000 (20:08 -0400) |
https://bugzilla.gnome.org/show_bug.cgi?id=621663
ext/x264/gstx264enc.c | patch | blob | history |
diff --git a/ext/x264/gstx264enc.c b/ext/x264/gstx264enc.c
index c1424e367806b8bc02df2cec2d916fc60900e493..82b1696c6a9aa42e1ecc2f158621c014f643c1e0 100644 (file)
--- a/ext/x264/gstx264enc.c
+++ b/ext/x264/gstx264enc.c
* of the encoding. This will similarly be the case if this target bitrate
* is to obtained in multiple (2 or 3) pass encoding.
* Alternatively, one may choose to perform Constant Quantizer or Quality encoding,
* in which case the #GstX264Enc:quantizer property controls much of the outcome.
*
* The H264 profile that is eventually used depends on a few settings.
* If #GstX264Enc:dct8x8 is enabled, then High profile is used.
case GST_X264_ENC_PASS_QUAL:
encoder->x264param.rc.i_rc_method = X264_RC_CRF;
encoder->x264param.rc.f_rf_constant = encoder->quantizer;
+ encoder->x264param.rc.i_vbv_max_bitrate = encoder->bitrate;
+ encoder->x264param.rc.i_vbv_buffer_size
+ = encoder->x264param.rc.i_vbv_max_bitrate
+ * encoder->vbv_buf_capacity / 1000;
break;
case GST_X264_ENC_PASS_CBR:
case GST_X264_ENC_PASS_PASS1:
@@
* is to obtained in multiple (2 or 3) pass encoding.
* Alternatively, one may choose to perform Constant Quantizer or Quality encoding,
- * in which case the #GstX264Enc:quantizer property controls much of the outcome.
+ * in which case the #GstX264Enc:quantizer property controls much of the outcome, in that case #GstX264Enc:bitrate is the maximum bitrate.
*
* The H264 profile that is eventually used depends on a few settings.